Class: AdyenApIs::CreateCheckoutSessionRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/adyen_ap_is/models/create_checkout_session_request.rb

Overview

CreateCheckoutSessionRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount:, merchant_account:, reference:, return_url:, account_info: SKIP, additional_amount: SKIP, additional_data: SKIP, allowed_payment_methods: SKIP, application_info: SKIP, authentication_data: SKIP, billing_address: SKIP, blocked_payment_methods: SKIP, capture_delay_hours: SKIP, channel: SKIP, company: SKIP, country_code: SKIP, date_of_birth: SKIP, deliver_at: SKIP, delivery_address: SKIP, enable_one_click: SKIP, enable_pay_out: SKIP, enable_recurring: SKIP, expires_at: SKIP, fund_origin: SKIP, fund_recipient: SKIP, installment_options: SKIP, line_items: SKIP, mandate: SKIP, mcc: SKIP, merchant_order_reference: SKIP, metadata: SKIP, mode: Mode::EMBEDDED, mpi_data: SKIP, platform_chargeback_logic: SKIP, recurring_expiry: SKIP, recurring_frequency: SKIP, recurring_processing_model: SKIP, redirect_from_issuer_method: SKIP, redirect_to_issuer_method: SKIP, risk_data: SKIP, shopper_email: SKIP, shopper_ip: SKIP, shopper_interaction: SKIP, shopper_locale: SKIP, shopper_name: SKIP, shopper_reference: SKIP, shopper_statement: SKIP, show_installment_amount: SKIP, show_remove_payment_method_button: SKIP, social_security_number: SKIP, split_card_funding_sources: false, splits: SKIP, store: SKIP, store_filtration_mode: SKIP, store_payment_method: SKIP, store_payment_method_mode: SKIP, telephone_number: SKIP, theme_id: SKIP, three_ds2_request_data: SKIP, three_ds_authentication_only: false, trusted_shopper: SKIP) ⇒ CreateCheckoutSessionRequest

Returns a new instance of CreateCheckoutSessionRequest.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 580

def initialize(amount:, merchant_account:, reference:, return_url:,
               account_info: SKIP, additional_amount: SKIP,
               additional_data: SKIP, allowed_payment_methods: SKIP,
               application_info: SKIP, authentication_data: SKIP,
               billing_address: SKIP, blocked_payment_methods: SKIP,
               capture_delay_hours: SKIP, channel: SKIP, company: SKIP,
               country_code: SKIP, date_of_birth: SKIP, deliver_at: SKIP,
               delivery_address: SKIP, enable_one_click: SKIP,
               enable_pay_out: SKIP, enable_recurring: SKIP,
               expires_at: SKIP, fund_origin: SKIP, fund_recipient: SKIP,
               installment_options: SKIP, line_items: SKIP, mandate: SKIP,
               mcc: SKIP, merchant_order_reference: SKIP, metadata: SKIP,
               mode: Mode::EMBEDDED, mpi_data: SKIP,
               platform_chargeback_logic: SKIP, recurring_expiry: SKIP,
               recurring_frequency: SKIP, recurring_processing_model: SKIP,
               redirect_from_issuer_method: SKIP,
               redirect_to_issuer_method: SKIP, risk_data: SKIP,
               shopper_email: SKIP, shopper_ip: SKIP,
               shopper_interaction: SKIP, shopper_locale: SKIP,
               shopper_name: SKIP, shopper_reference: SKIP,
               shopper_statement: SKIP, show_installment_amount: SKIP,
               show_remove_payment_method_button: SKIP,
               social_security_number: SKIP,
               split_card_funding_sources: false, splits: SKIP, store: SKIP,
               store_filtration_mode: SKIP, store_payment_method: SKIP,
               store_payment_method_mode: SKIP, telephone_number: SKIP,
               theme_id: SKIP, three_ds2_request_data: SKIP,
               three_ds_authentication_only: false, trusted_shopper: SKIP)
  @account_info =  unless  == SKIP
  @additional_amount = additional_amount unless additional_amount == SKIP
  @additional_data = additional_data unless additional_data == SKIP
  @allowed_payment_methods = allowed_payment_methods unless allowed_payment_methods == SKIP
  @amount = amount
  @application_info = application_info unless application_info == SKIP
  @authentication_data = authentication_data unless authentication_data == SKIP
  @billing_address = billing_address unless billing_address == SKIP
  @blocked_payment_methods = blocked_payment_methods unless blocked_payment_methods == SKIP
  @capture_delay_hours = capture_delay_hours unless capture_delay_hours == SKIP
  @channel = channel unless channel == SKIP
  @company = company unless company == SKIP
  @country_code = country_code unless country_code == SKIP
  @date_of_birth = date_of_birth unless date_of_birth == SKIP
  @deliver_at = deliver_at unless deliver_at == SKIP
  @delivery_address = delivery_address unless delivery_address == SKIP
  @enable_one_click = enable_one_click unless enable_one_click == SKIP
  @enable_pay_out = enable_pay_out unless enable_pay_out == SKIP
  @enable_recurring = enable_recurring unless enable_recurring == SKIP
  @expires_at = expires_at unless expires_at == SKIP
  @fund_origin = fund_origin unless fund_origin == SKIP
  @fund_recipient = fund_recipient unless fund_recipient == SKIP
  @installment_options = installment_options unless installment_options == SKIP
  @line_items = line_items unless line_items == SKIP
  @mandate = mandate unless mandate == SKIP
  @mcc = mcc unless mcc == SKIP
  @merchant_account = 
  @merchant_order_reference = merchant_order_reference unless merchant_order_reference == SKIP
  @metadata =  unless  == SKIP
  @mode = mode unless mode == SKIP
  @mpi_data = mpi_data unless mpi_data == SKIP
  unless platform_chargeback_logic == SKIP
    @platform_chargeback_logic =
      platform_chargeback_logic
  end
  @recurring_expiry = recurring_expiry unless recurring_expiry == SKIP
  @recurring_frequency = recurring_frequency unless recurring_frequency == SKIP
  unless recurring_processing_model == SKIP
    @recurring_processing_model =
      recurring_processing_model
  end
  unless redirect_from_issuer_method == SKIP
    @redirect_from_issuer_method =
      redirect_from_issuer_method
  end
  unless redirect_to_issuer_method == SKIP
    @redirect_to_issuer_method =
      redirect_to_issuer_method
  end
  @reference = reference
  @return_url = return_url
  @risk_data = risk_data unless risk_data == SKIP
  @shopper_email = shopper_email unless shopper_email == SKIP
  @shopper_ip = shopper_ip unless shopper_ip == SKIP
  @shopper_interaction = shopper_interaction unless shopper_interaction == SKIP
  @shopper_locale = shopper_locale unless shopper_locale == SKIP
  @shopper_name = shopper_name unless shopper_name == SKIP
  @shopper_reference = shopper_reference unless shopper_reference == SKIP
  @shopper_statement = shopper_statement unless shopper_statement == SKIP
  @show_installment_amount = show_installment_amount unless show_installment_amount == SKIP
  unless show_remove_payment_method_button == SKIP
    @show_remove_payment_method_button =
      show_remove_payment_method_button
  end
  @social_security_number = social_security_number unless social_security_number == SKIP
  unless split_card_funding_sources == SKIP
    @split_card_funding_sources =
      split_card_funding_sources
  end
  @splits = splits unless splits == SKIP
  @store = store unless store == SKIP
  @store_filtration_mode = store_filtration_mode unless store_filtration_mode == SKIP
  @store_payment_method = store_payment_method unless store_payment_method == SKIP
  unless store_payment_method_mode == SKIP
    @store_payment_method_mode =
      store_payment_method_mode
  end
  @telephone_number = telephone_number unless telephone_number == SKIP
  @theme_id = theme_id unless theme_id == SKIP
  @three_ds2_request_data = three_ds2_request_data unless three_ds2_request_data == SKIP
  unless three_ds_authentication_only == SKIP
    @three_ds_authentication_only =
      three_ds_authentication_only
  end
  @trusted_shopper = trusted_shopper unless trusted_shopper == SKIP
end

Instance Attribute Details

#account_infoAccountInfo1

Shopper account information for 3D Secure 2.

For 3D Secure 2 transactions, we recommend that you include this object to increase the chances of achieving a frictionless flow.

Returns:



17
18
19
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 17

def 
  @account_info
end

#additional_amountAmount1

If you want a [BIN or card verification](https://docs.adyen.com/payment-methods/cards/bin-data-and-ca rd-verification) request to use a non-zero value, assign this value to additionalAmount (while the amount must be still set to 0 to trigger BIN or card verification). Required to be in the same currency as the amount.

Returns:



26
27
28
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 26

def additional_amount
  @additional_amount
end

#additional_dataHash[String, String]

This field contains additional data, which may be required for a particular payment request. The additionalData object consists of entries, each of which includes the key and value.

Returns:

  • (Hash[String, String])


33
34
35
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 33

def additional_data
  @additional_data
end

#allowed_payment_methodsArray[String]

List of payment methods to be presented to the shopper. To refer to payment methods, use their payment method type. Example: "allowedPaymentMethods":["ideal","applepay"]

Returns:

  • (Array[String])


40
41
42
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 40

def allowed_payment_methods
  @allowed_payment_methods
end

#amountAmount17

The amount of the payment.

Returns:



44
45
46
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 44

def amount
  @amount
end

#application_infoApplicationInfo1

Information about your application. For more details, see [Building Adyen solutions](https://docs.adyen.com/development-resources/building-adyen-sol utions).

Returns:



50
51
52
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 50

def application_info
  @application_info
end

#authentication_dataAuthenticationData1

Configuration data for 3DS payments.

Returns:



54
55
56
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 54

def authentication_data
  @authentication_data
end

#billing_addressBillingAddress1

The address where to send the invoice.

Returns:



58
59
60
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 58

def billing_address
  @billing_address
end

#blocked_payment_methodsArray[String]

List of payment methods to be hidden from the shopper. To refer to payment methods, use their payment method type. Example: "blockedPaymentMethods":["ideal","applepay"]

Returns:

  • (Array[String])


65
66
67
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 65

def blocked_payment_methods
  @blocked_payment_methods
end

#capture_delay_hoursInteger

The delay between the authorisation and scheduled auto-capture, specified in hours.

Returns:

  • (Integer)


70
71
72
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 70

def capture_delay_hours
  @capture_delay_hours
end

#channelChannel

The platform where a payment transaction takes place. This field is optional for filtering out payment methods that are only available on specific platforms. If this value is not set, then we will try to infer it from the sdkVersion or token. Possible values:

  • iOS
  • Android
  • Web

Returns:



81
82
83
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 81

def channel
  @channel
end

#companyCompany1

Information regarding the company.

Returns:



85
86
87
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 85

def company
  @company
end

#country_codeString

The shopper's two-letter country code.

Returns:

  • (String)


89
90
91
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 89

def country_code
  @country_code
end

#date_of_birthDate

The shopper's date of birth. Format ISO-8601: YYYY-MM-DD

Returns:

  • (Date)


94
95
96
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 94

def date_of_birth
  @date_of_birth
end

#deliver_atDateTime

The date and time when the purchased goods should be delivered. ISO 8601 format: YYYY-MM-DDThh:mm:ss+TZD, for example, 2020-12-18T10:15:30+01:00.

Returns:

  • (DateTime)


100
101
102
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 100

def deliver_at
  @deliver_at
end

#delivery_addressDeliveryAddress1

The address where the purchased goods should be delivered.

Returns:



104
105
106
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 104

def delivery_address
  @delivery_address
end

#enable_one_clickTrueClass | FalseClass

When true and shopperReference is provided, the shopper will be asked if the payment details should be stored for future [one-click payments](https://docs.adyen.com/get-started-with-adyen/payment-glossary/# one-click-payments-definition).

Returns:

  • (TrueClass | FalseClass)


111
112
113
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 111

def enable_one_click
  @enable_one_click
end

#enable_pay_outTrueClass | FalseClass

When true and shopperReference is provided, the payment details will be tokenized for payouts.

Returns:

  • (TrueClass | FalseClass)


116
117
118
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 116

def enable_pay_out
  @enable_pay_out
end

#enable_recurringTrueClass | FalseClass

When true and shopperReference is provided, the payment details will be stored for [recurring payments](https://docs.adyen.com/online-payments/tokenization/#recurring-p ayment-types) where the shopper is not present, such as subscription or automatic top-up payments.

Returns:

  • (TrueClass | FalseClass)


124
125
126
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 124

def enable_recurring
  @enable_recurring
end

#expires_atDateTime

The date the session expires in ISO8601 format. When not specified, the expiry date is set to 1 hour after session creation. You cannot set the session expiry to more than 24 hours after session creation.

Returns:

  • (DateTime)


132
133
134
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 132

def expires_at
  @expires_at
end

#fund_originFundOrigin1

The person or entity funding the money.

Returns:



136
137
138
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 136

def fund_origin
  @fund_origin
end

#fund_recipientFundRecipient1

the person or entity receiving the money

Returns:



140
141
142
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 140

def fund_recipient
  @fund_recipient
end

#installment_optionsHash[String, CheckoutSessionInstallmentOption]

A set of key-value pairs that specifies the installment options available per payment method. The key must be a payment method name in lowercase. For example, card to specify installment options for all cards, or visa or mc. The value must be an object containing the installment options.

Returns:



148
149
150
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 148

def installment_options
  @installment_options
end

#line_itemsArray[LineItem]

Price and product information about the purchased items, to be included on the invoice sent to the shopper.

This field is required for 3x 4x Oney, Affirm, Afterpay, Clearpay, Klarna, Ratepay, and Riverty.

Returns:



155
156
157
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 155

def line_items
  @line_items
end

#mandateMandate1

The mandate details to initiate recurring transaction.

Returns:



159
160
161
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 159

def mandate
  @mandate
end

#mccString

The merchant category code (MCC) is a four-digit number, which relates to a particular market segment. This code reflects the predominant activity that is conducted by the merchant.

Returns:

  • (String)


166
167
168
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 166

def mcc
  @mcc
end

#merchant_accountString

The merchant account identifier, with which you want to process the transaction.

Returns:

  • (String)


171
172
173
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 171

def 
  @merchant_account
end

#merchant_order_referenceString

This reference allows linking multiple transactions to each other for reporting purposes (i.e. order auth-rate). The reference should be unique per billing cycle. The same merchant order reference should never be reused after the first authorised attempt. If used, this field should be supplied for all incoming authorisations.

We strongly recommend you send the merchantOrderReference value to benefit from linking payment requests when authorisation retries take place. In addition, we recommend you provide retry.orderAttemptNumber, retry.chainAttemptNumber, and retry.skipRetry values in PaymentRequest.additionalData.

Returns:

  • (String)


185
186
187
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 185

def merchant_order_reference
  @merchant_order_reference
end

#metadataHash[String, String]

Metadata consists of entries, each of which includes a key and a value. Limits:

  • Maximum 20 key-value pairs per request.
  • Maximum 20 characters per key.
  • Maximum 80 characters per value.

Returns:

  • (Hash[String, String])


193
194
195
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 193

def 
  @metadata
end

#modeMode

Indicates the type of front end integration. Possible values:

  • embedded (default): Drop-in or Components integration
  • hosted: Hosted Checkout integration

Returns:



199
200
201
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 199

def mode
  @mode
end

#mpi_dataThreeDSecureData1

Authentication data produced by an MPI (Mastercard SecureCode, Visa Secure, or Cartes Bancaires).

Returns:



204
205
206
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 204

def mpi_data
  @mpi_data
end

#platform_chargeback_logicPlatformChargebackLogic1

Defines how to book chargebacks when using Adyen for Platforms.



209
210
211
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 209

def platform_chargeback_logic
  @platform_chargeback_logic
end

#recurring_expiryString

Date after which no further authorisations shall be performed. Only for 3D Secure 2.

Returns:

  • (String)


214
215
216
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 214

def recurring_expiry
  @recurring_expiry
end

#recurring_frequencyString

Minimum number of days between authorisations. Only for 3D Secure 2.

Returns:

  • (String)


218
219
220
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 218

def recurring_frequency
  @recurring_frequency
end

#recurring_processing_modelRecurringProcessingModel1

Defines a recurring payment type. Required when creating a token to store payment details. Allowed values:

  • Subscription – A transaction for a fixed or variable amount, which follows a fixed schedule.
  • CardOnFile – With a card-on-file (CoF) transaction, card details are stored to enable one-click or omnichannel journeys, or simply to streamline the checkout process. Any subscription not following a fixed schedule is also considered a card-on-file transaction.
  • UnscheduledCardOnFile – An unscheduled card-on-file (UCoF) transaction is a transaction that occurs on a non-fixed schedule and/or have variable amounts. For example, automatic top-ups when a cardholder's balance drops below a certain amount.


234
235
236
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 234

def recurring_processing_model
  @recurring_processing_model
end

#redirect_from_issuer_methodString

Specifies the redirect method (GET or POST) when redirecting back from the issuer.

Returns:

  • (String)


239
240
241
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 239

def redirect_from_issuer_method
  @redirect_from_issuer_method
end

#redirect_to_issuer_methodString

Specifies the redirect method (GET or POST) when redirecting to the issuer.

Returns:

  • (String)


244
245
246
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 244

def redirect_to_issuer_method
  @redirect_to_issuer_method
end

#referenceString

The reference to uniquely identify a payment.

Returns:

  • (String)


248
249
250
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 248

def reference
  @reference
end

#return_urlString

The URL to return to in case of a redirection. The format depends on the channel.

  • For web, include the protocol http:// or https://. You can also include your own additional query parameters, for example, shopper ID or order reference number. Example: https://your-company.example.com/checkout?shopperOrder=12xy
  • For iOS, use the custom URL for your app. To know more about setting custom URL schemes, refer to the [Apple Developer documentation](https://developer.apple.com/documentation/uikit/inter-proce ss_communication/allowing_apps_and_websites_to_link_to_your_content/defini ng_a_custom_url_scheme_for_your_app). Example: my-app://
  • For Android, use a custom URL handled by an Activity on your app. You can configure it with an intent filter. Example: my-app://your.package.name If the URL to return to includes non-ASCII characters, like spaces or special letters, URL encode the value. We strongly recommend that you use a maximum of 1024 characters.

The URL must not include personally identifiable information (PII), for example name or email address.

Returns:

  • (String)


272
273
274
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 272

def return_url
  @return_url
end

#risk_dataRiskData1

Any risk-related settings to apply to the payment.

Returns:



276
277
278
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 276

def risk_data
  @risk_data
end

#shopper_emailString

The shopper's email address.

Returns:

  • (String)


280
281
282
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 280

def shopper_email
  @shopper_email
end

#shopper_interactionShopperInteraction

Specifies the sales channel, through which the shopper gives their card details, and whether the shopper is a returning customer. For the web service API, Adyen assumes Ecommerce shopper interaction by default. This field has the following possible values:

  • Ecommerce - Online transactions where the cardholder is present (online). For better authorisation rates, we recommend sending the card security code (CSC) along with the request.
  • ContAuth - Card on file and/or subscription transactions, where the cardholder is known to the merchant (returning customer). If the shopper is present (online), you can supply also the CSC to improve authorisation (one-click payment).
  • Moto - Mail-order and telephone-order transactions where the shopper is in contact with the merchant via email or telephone.
  • POS - Point-of-sale transactions where the shopper is physically present to make a payment using a secure payment terminal.

Returns:



312
313
314
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 312

def shopper_interaction
  @shopper_interaction
end

#shopper_ipString

The shopper's IP address. We recommend that you provide this data, as it is used in a number of risk checks (for instance, number of payment attempts or location-based checks).

Required for Visa and JCB transactions that require 3D Secure 2 authentication for all web and mobile integrations, if you did not include the shopperEmail. For native mobile integrations, the field is required to support cases where authentication is routed to the redirect flow. This field is also mandatory for some merchants depending on your business model. For more information, contact Support.

Returns:

  • (String)


293
294
295
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 293

def shopper_ip
  @shopper_ip
end

#shopper_localeString

The combination of a language code and a country code to specify the language to be used in the payment.

Returns:

  • (String)


317
318
319
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 317

def shopper_locale
  @shopper_locale
end

#shopper_nameShopperName1

The shopper's full name. This object is required for some payment methods such as AfterPay, Klarna, or if you're enrolled in the PayPal Seller Protection program.

Returns:



323
324
325
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 323

def shopper_name
  @shopper_name
end

#shopper_referenceString

Your reference to uniquely identify this shopper, for example user ID or account ID. The value is case-sensitive and must be at least three characters.

Your reference must not include personally identifiable information (PII) such as name or email address.

Returns:

  • (String)


331
332
333
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 331

def shopper_reference
  @shopper_reference
end

#shopper_statementString

The text to be shown on the shopper's bank statement. We recommend sending a maximum of 22 characters, otherwise banks might truncate the string. Allowed characters: a-z, A-Z, 0-9, spaces, and special characters . , ' _ - ? + * /.

Returns:

  • (String)


339
340
341
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 339

def shopper_statement
  @shopper_statement
end

#show_installment_amountTrueClass | FalseClass

Set to true to show the payment amount per installment.

Returns:

  • (TrueClass | FalseClass)


343
344
345
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 343

def show_installment_amount
  @show_installment_amount
end

#show_remove_payment_method_buttonTrueClass | FalseClass

Set to true to show a button that lets the shopper remove a stored payment method.

Returns:

  • (TrueClass | FalseClass)


348
349
350
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 348

def show_remove_payment_method_button
  @show_remove_payment_method_button
end

#social_security_numberString

The shopper's social security number.

Returns:

  • (String)


352
353
354
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 352

def social_security_number
  @social_security_number
end

#split_card_funding_sourcesTrueClass | FalseClass

Boolean value indicating whether the card payment method should be split into separate debit and credit options.

Returns:

  • (TrueClass | FalseClass)


357
358
359
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 357

def split_card_funding_sources
  @split_card_funding_sources
end

#splitsArray[Split]

An array of objects specifying how to split a payment when using [Adyen for Platforms](https://docs.adyen.com/platforms/process-payments#providing-spl it-information), [Classic Platforms integration](https://docs.adyen.com/classic-platforms/processing-payments# providing-split-information), or Issuing.

Returns:



367
368
369
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 367

def splits
  @splits
end

#storeString

Required for Adyen for Platforms integrations if you are a platform model. This is your [reference](https://docs.adyen.com/api-explorer/Management/3/post/merchant s/(merchantId)/stores#request-reference) (on balance platform) or the [storeReference](https://docs.adyen.com/api-explorer/Account/latest/post/u pdateAccountHolder#request-accountHolderDetails-storeDetails-storeReferenc e) (in the [classic integration](https://docs.adyen.com/classic-platforms/processing-payments/ route-payment-to-store/#route-a-payment-to-a-store)) for the ecommerce or point-of-sale store that is processing the payment.

Returns:

  • (String)


381
382
383
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 381

def store
  @store
end

#store_filtration_modeStoreFiltrationMode

Specifies how payment methods should be filtered based on the 'store' parameter:

  • 'exclusive': Only payment methods belonging to the specified 'store' are returned.
  • 'inclusive': Payment methods from the 'store' and those not associated with any other store are returned.

Returns:



390
391
392
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 390

def store_filtration_mode
  @store_filtration_mode
end

#store_payment_methodTrueClass | FalseClass

When true and shopperReference is provided, the payment details will be stored for future [recurring payments](https://docs.adyen.com/online-payments/tokenization/#recurring-p ayment-types).

Returns:

  • (TrueClass | FalseClass)


397
398
399
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 397

def store_payment_method
  @store_payment_method
end

#store_payment_method_modeStorePaymentMethodMode

Indicates if the details of the payment method will be stored for the shopper. Possible values:

  • disabled – No details will be stored (default).
  • askForConsent – If the shopperReference is provided, the Drop-in/Component shows a checkbox where the shopper can select to store their payment details for card payments.
  • enabled – If the shopperReference is provided, the details will be stored without asking the shopper for consent.


408
409
410
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 408

def store_payment_method_mode
  @store_payment_method_mode
end

#telephone_numberString

The shopper's telephone number. The phone number must include a plus sign (+) and a country code (1-3 digits), followed by the number (4-15 digits). If the value you provide does not follow the guidelines, we do not submit it for authentication.

Required for Visa and JCB transactions that require 3D Secure 2 authentication, if you did not include the shopperEmail.

Returns:

  • (String)


417
418
419
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 417

def telephone_number
  @telephone_number
end

#theme_idString

Sets a custom theme for [Hosted Checkout](https://docs.adyen.com/online-payments/build-your-integration/?p latform=Web&integration=Hosted+Checkout). The value can be any of the Theme ID values from your Customer Area.

Returns:

  • (String)


424
425
426
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 424

def theme_id
  @theme_id
end

#three_ds2_request_dataCheckoutSessionThreeDs2RequestData1

Request fields for 3D Secure 2. To check if any of the following fields are required for your integration, refer to Online payments.



430
431
432
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 430

def three_ds2_request_data
  @three_ds2_request_data
end

#three_ds_authentication_onlyTrueClass | FalseClass

Required to trigger the [authentication-only flow](https://docs.adyen.com/online-payments/3d-secure/authentication-only /). If set to true, you will only perform the 3D Secure 2 authentication, and will not proceed to the payment authorization.Default: false.

Returns:

  • (TrueClass | FalseClass)


438
439
440
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 438

def three_ds_authentication_only
  @three_ds_authentication_only
end

#trusted_shopperTrueClass | FalseClass

Set to true if the payment should be routed to a trusted MID.

Returns:

  • (TrueClass | FalseClass)


442
443
444
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 442

def trusted_shopper
  @trusted_shopper
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 696

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = Amount17.from_hash(hash['amount']) if hash['amount']
   =
    hash.key?('merchantAccount') ? hash['merchantAccount'] : nil
  reference = hash.key?('reference') ? hash['reference'] : nil
  return_url = hash.key?('returnUrl') ? hash['returnUrl'] : nil
   = AccountInfo1.from_hash(hash['accountInfo']) if hash['accountInfo']
  additional_amount = Amount1.from_hash(hash['additionalAmount']) if hash['additionalAmount']
  additional_data =
    hash.key?('additionalData') ? hash['additionalData'] : SKIP
  allowed_payment_methods =
    hash.key?('allowedPaymentMethods') ? hash['allowedPaymentMethods'] : SKIP
  application_info = ApplicationInfo1.from_hash(hash['applicationInfo']) if
    hash['applicationInfo']
  authentication_data = AuthenticationData1.from_hash(hash['authenticationData']) if
    hash['authenticationData']
  billing_address = BillingAddress1.from_hash(hash['billingAddress']) if
    hash['billingAddress']
  blocked_payment_methods =
    hash.key?('blockedPaymentMethods') ? hash['blockedPaymentMethods'] : SKIP
  capture_delay_hours =
    hash.key?('captureDelayHours') ? hash['captureDelayHours'] : SKIP
  channel = hash.key?('channel') ? hash['channel'] : SKIP
  company = Company1.from_hash(hash['company']) if hash['company']
  country_code = hash.key?('countryCode') ? hash['countryCode'] : SKIP
  date_of_birth = hash.key?('dateOfBirth') ? hash['dateOfBirth'] : SKIP
  deliver_at = if hash.key?('deliverAt')
                 (DateTimeHelper.from_rfc3339(hash['deliverAt']) if hash['deliverAt'])
               else
                 SKIP
               end
  delivery_address = DeliveryAddress1.from_hash(hash['deliveryAddress']) if
    hash['deliveryAddress']
  enable_one_click =
    hash.key?('enableOneClick') ? hash['enableOneClick'] : SKIP
  enable_pay_out = hash.key?('enablePayOut') ? hash['enablePayOut'] : SKIP
  enable_recurring =
    hash.key?('enableRecurring') ? hash['enableRecurring'] : SKIP
  expires_at = if hash.key?('expiresAt')
                 (DateTimeHelper.from_rfc3339(hash['expiresAt']) if hash['expiresAt'])
               else
                 SKIP
               end
  fund_origin = FundOrigin1.from_hash(hash['fundOrigin']) if hash['fundOrigin']
  fund_recipient = FundRecipient1.from_hash(hash['fundRecipient']) if hash['fundRecipient']
  if hash['installmentOptions']
    installment_options = CheckoutSessionInstallmentOption.from_hash(hash['installmentOptions'])
  end

  installment_options = SKIP unless hash.key?('installmentOptions')
  # Parameter is an array, so we need to iterate through it
  line_items = nil
  unless hash['lineItems'].nil?
    line_items = []
    hash['lineItems'].each do |structure|
      line_items << (LineItem.from_hash(structure) if structure)
    end
  end

  line_items = SKIP unless hash.key?('lineItems')
  mandate = Mandate1.from_hash(hash['mandate']) if hash['mandate']
  mcc = hash.key?('mcc') ? hash['mcc'] : SKIP
  merchant_order_reference =
    hash.key?('merchantOrderReference') ? hash['merchantOrderReference'] : SKIP
   = hash.key?('metadata') ? hash['metadata'] : SKIP
  mode = hash['mode'] ||= Mode::EMBEDDED
  mpi_data = ThreeDSecureData1.from_hash(hash['mpiData']) if hash['mpiData']
  if hash['platformChargebackLogic']
    platform_chargeback_logic = PlatformChargebackLogic1.from_hash(hash['platformChargebackLogic'])
  end
  recurring_expiry =
    hash.key?('recurringExpiry') ? hash['recurringExpiry'] : SKIP
  recurring_frequency =
    hash.key?('recurringFrequency') ? hash['recurringFrequency'] : SKIP
  recurring_processing_model =
    hash.key?('recurringProcessingModel') ? hash['recurringProcessingModel'] : SKIP
  redirect_from_issuer_method =
    hash.key?('redirectFromIssuerMethod') ? hash['redirectFromIssuerMethod'] : SKIP
  redirect_to_issuer_method =
    hash.key?('redirectToIssuerMethod') ? hash['redirectToIssuerMethod'] : SKIP
  risk_data = RiskData1.from_hash(hash['riskData']) if hash['riskData']
  shopper_email = hash.key?('shopperEmail') ? hash['shopperEmail'] : SKIP
  shopper_ip = hash.key?('shopperIP') ? hash['shopperIP'] : SKIP
  shopper_interaction =
    hash.key?('shopperInteraction') ? hash['shopperInteraction'] : SKIP
  shopper_locale = hash.key?('shopperLocale') ? hash['shopperLocale'] : SKIP
  shopper_name = ShopperName1.from_hash(hash['shopperName']) if hash['shopperName']
  shopper_reference =
    hash.key?('shopperReference') ? hash['shopperReference'] : SKIP
  shopper_statement =
    hash.key?('shopperStatement') ? hash['shopperStatement'] : SKIP
  show_installment_amount =
    hash.key?('showInstallmentAmount') ? hash['showInstallmentAmount'] : SKIP
  show_remove_payment_method_button =
    hash.key?('showRemovePaymentMethodButton') ? hash['showRemovePaymentMethodButton'] : SKIP
  social_security_number =
    hash.key?('socialSecurityNumber') ? hash['socialSecurityNumber'] : SKIP
  split_card_funding_sources = hash['splitCardFundingSources'] ||= false
  # Parameter is an array, so we need to iterate through it
  splits = nil
  unless hash['splits'].nil?
    splits = []
    hash['splits'].each do |structure|
      splits << (Split.from_hash(structure) if structure)
    end
  end

  splits = SKIP unless hash.key?('splits')
  store = hash.key?('store') ? hash['store'] : SKIP
  store_filtration_mode =
    hash.key?('storeFiltrationMode') ? hash['storeFiltrationMode'] : SKIP
  store_payment_method =
    hash.key?('storePaymentMethod') ? hash['storePaymentMethod'] : SKIP
  store_payment_method_mode =
    hash.key?('storePaymentMethodMode') ? hash['storePaymentMethodMode'] : SKIP
  telephone_number =
    hash.key?('telephoneNumber') ? hash['telephoneNumber'] : SKIP
  theme_id = hash.key?('themeId') ? hash['themeId'] : SKIP
  if hash['threeDS2RequestData']
    three_ds2_request_data = CheckoutSessionThreeDs2RequestData1.from_hash(hash['threeDS2RequestData'])
  end
  three_ds_authentication_only = hash['threeDSAuthenticationOnly'] ||= false
  trusted_shopper =
    hash.key?('trustedShopper') ? hash['trustedShopper'] : SKIP

  # Create object from extracted values.
  CreateCheckoutSessionRequest.new(amount: amount,
                                   merchant_account: ,
                                   reference: reference,
                                   return_url: return_url,
                                   account_info: ,
                                   additional_amount: additional_amount,
                                   additional_data: additional_data,
                                   allowed_payment_methods: allowed_payment_methods,
                                   application_info: application_info,
                                   authentication_data: authentication_data,
                                   billing_address: billing_address,
                                   blocked_payment_methods: blocked_payment_methods,
                                   capture_delay_hours: capture_delay_hours,
                                   channel: channel,
                                   company: company,
                                   country_code: country_code,
                                   date_of_birth: date_of_birth,
                                   deliver_at: deliver_at,
                                   delivery_address: delivery_address,
                                   enable_one_click: enable_one_click,
                                   enable_pay_out: enable_pay_out,
                                   enable_recurring: enable_recurring,
                                   expires_at: expires_at,
                                   fund_origin: fund_origin,
                                   fund_recipient: fund_recipient,
                                   installment_options: installment_options,
                                   line_items: line_items,
                                   mandate: mandate,
                                   mcc: mcc,
                                   merchant_order_reference: merchant_order_reference,
                                   metadata: ,
                                   mode: mode,
                                   mpi_data: mpi_data,
                                   platform_chargeback_logic: platform_chargeback_logic,
                                   recurring_expiry: recurring_expiry,
                                   recurring_frequency: recurring_frequency,
                                   recurring_processing_model: recurring_processing_model,
                                   redirect_from_issuer_method: redirect_from_issuer_method,
                                   redirect_to_issuer_method: redirect_to_issuer_method,
                                   risk_data: risk_data,
                                   shopper_email: shopper_email,
                                   shopper_ip: shopper_ip,
                                   shopper_interaction: shopper_interaction,
                                   shopper_locale: shopper_locale,
                                   shopper_name: shopper_name,
                                   shopper_reference: shopper_reference,
                                   shopper_statement: shopper_statement,
                                   show_installment_amount: show_installment_amount,
                                   show_remove_payment_method_button: show_remove_payment_method_button,
                                   social_security_number: social_security_number,
                                   split_card_funding_sources: split_card_funding_sources,
                                   splits: splits,
                                   store: store,
                                   store_filtration_mode: store_filtration_mode,
                                   store_payment_method: store_payment_method,
                                   store_payment_method_mode: store_payment_method_mode,
                                   telephone_number: telephone_number,
                                   theme_id: theme_id,
                                   three_ds2_request_data: three_ds2_request_data,
                                   three_ds_authentication_only: three_ds_authentication_only,
                                   trusted_shopper: trusted_shopper)
end

.namesObject

A mapping from model property names to API property names.



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 445

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_info'] = 'accountInfo'
  @_hash['additional_amount'] = 'additionalAmount'
  @_hash['additional_data'] = 'additionalData'
  @_hash['allowed_payment_methods'] = 'allowedPaymentMethods'
  @_hash['amount'] = 'amount'
  @_hash['application_info'] = 'applicationInfo'
  @_hash['authentication_data'] = 'authenticationData'
  @_hash['billing_address'] = 'billingAddress'
  @_hash['blocked_payment_methods'] = 'blockedPaymentMethods'
  @_hash['capture_delay_hours'] = 'captureDelayHours'
  @_hash['channel'] = 'channel'
  @_hash['company'] = 'company'
  @_hash['country_code'] = 'countryCode'
  @_hash['date_of_birth'] = 'dateOfBirth'
  @_hash['deliver_at'] = 'deliverAt'
  @_hash['delivery_address'] = 'deliveryAddress'
  @_hash['enable_one_click'] = 'enableOneClick'
  @_hash['enable_pay_out'] = 'enablePayOut'
  @_hash['enable_recurring'] = 'enableRecurring'
  @_hash['expires_at'] = 'expiresAt'
  @_hash['fund_origin'] = 'fundOrigin'
  @_hash['fund_recipient'] = 'fundRecipient'
  @_hash['installment_options'] = 'installmentOptions'
  @_hash['line_items'] = 'lineItems'
  @_hash['mandate'] = 'mandate'
  @_hash['mcc'] = 'mcc'
  @_hash['merchant_account'] = 'merchantAccount'
  @_hash['merchant_order_reference'] = 'merchantOrderReference'
  @_hash['metadata'] = 'metadata'
  @_hash['mode'] = 'mode'
  @_hash['mpi_data'] = 'mpiData'
  @_hash['platform_chargeback_logic'] = 'platformChargebackLogic'
  @_hash['recurring_expiry'] = 'recurringExpiry'
  @_hash['recurring_frequency'] = 'recurringFrequency'
  @_hash['recurring_processing_model'] = 'recurringProcessingModel'
  @_hash['redirect_from_issuer_method'] = 'redirectFromIssuerMethod'
  @_hash['redirect_to_issuer_method'] = 'redirectToIssuerMethod'
  @_hash['reference'] = 'reference'
  @_hash['return_url'] = 'returnUrl'
  @_hash['risk_data'] = 'riskData'
  @_hash['shopper_email'] = 'shopperEmail'
  @_hash['shopper_ip'] = 'shopperIP'
  @_hash['shopper_interaction'] = 'shopperInteraction'
  @_hash['shopper_locale'] = 'shopperLocale'
  @_hash['shopper_name'] = 'shopperName'
  @_hash['shopper_reference'] = 'shopperReference'
  @_hash['shopper_statement'] = 'shopperStatement'
  @_hash['show_installment_amount'] = 'showInstallmentAmount'
  @_hash['show_remove_payment_method_button'] =
    'showRemovePaymentMethodButton'
  @_hash['social_security_number'] = 'socialSecurityNumber'
  @_hash['split_card_funding_sources'] = 'splitCardFundingSources'
  @_hash['splits'] = 'splits'
  @_hash['store'] = 'store'
  @_hash['store_filtration_mode'] = 'storeFiltrationMode'
  @_hash['store_payment_method'] = 'storePaymentMethod'
  @_hash['store_payment_method_mode'] = 'storePaymentMethodMode'
  @_hash['telephone_number'] = 'telephoneNumber'
  @_hash['theme_id'] = 'themeId'
  @_hash['three_ds2_request_data'] = 'threeDS2RequestData'
  @_hash['three_ds_authentication_only'] = 'threeDSAuthenticationOnly'
  @_hash['trusted_shopper'] = 'trustedShopper'
  @_hash
end

.nullablesObject

An array for nullable fields



576
577
578
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 576

def self.nullables
  []
end

.optionalsObject

An array for optional fields



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 513

def self.optionals
  %w[
    account_info
    additional_amount
    additional_data
    allowed_payment_methods
    application_info
    authentication_data
    billing_address
    blocked_payment_methods
    capture_delay_hours
    channel
    company
    country_code
    date_of_birth
    deliver_at
    delivery_address
    enable_one_click
    enable_pay_out
    enable_recurring
    expires_at
    fund_origin
    fund_recipient
    installment_options
    line_items
    mandate
    mcc
    merchant_order_reference
    metadata
    mode
    mpi_data
    platform_chargeback_logic
    recurring_expiry
    recurring_frequency
    recurring_processing_model
    redirect_from_issuer_method
    redirect_to_issuer_method
    risk_data
    shopper_email
    shopper_ip
    shopper_interaction
    shopper_locale
    shopper_name
    shopper_reference
    shopper_statement
    show_installment_amount
    show_remove_payment_method_button
    social_security_number
    split_card_funding_sources
    splits
    store
    store_filtration_mode
    store_payment_method
    store_payment_method_mode
    telephone_number
    theme_id
    three_ds2_request_data
    three_ds_authentication_only
    trusted_shopper
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 933

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_info: #{@account_info.inspect}, additional_amount:"\
  " #{@additional_amount.inspect}, additional_data: #{@additional_data.inspect},"\
  " allowed_payment_methods: #{@allowed_payment_methods.inspect}, amount: #{@amount.inspect},"\
  " application_info: #{@application_info.inspect}, authentication_data:"\
  " #{@authentication_data.inspect}, billing_address: #{@billing_address.inspect},"\
  " blocked_payment_methods: #{@blocked_payment_methods.inspect}, capture_delay_hours:"\
  " #{@capture_delay_hours.inspect}, channel: #{@channel.inspect}, company:"\
  " #{@company.inspect}, country_code: #{@country_code.inspect}, date_of_birth:"\
  " #{@date_of_birth.inspect}, deliver_at: #{@deliver_at.inspect}, delivery_address:"\
  " #{@delivery_address.inspect}, enable_one_click: #{@enable_one_click.inspect},"\
  " enable_pay_out: #{@enable_pay_out.inspect}, enable_recurring:"\
  " #{@enable_recurring.inspect}, expires_at: #{@expires_at.inspect}, fund_origin:"\
  " #{@fund_origin.inspect}, fund_recipient: #{@fund_recipient.inspect}, installment_options:"\
  " #{@installment_options.inspect}, line_items: #{@line_items.inspect}, mandate:"\
  " #{@mandate.inspect}, mcc: #{@mcc.inspect}, merchant_account: #{@merchant_account.inspect},"\
  " merchant_order_reference: #{@merchant_order_reference.inspect}, metadata:"\
  " #{@metadata.inspect}, mode: #{@mode.inspect}, mpi_data: #{@mpi_data.inspect},"\
  " platform_chargeback_logic: #{@platform_chargeback_logic.inspect}, recurring_expiry:"\
  " #{@recurring_expiry.inspect}, recurring_frequency: #{@recurring_frequency.inspect},"\
  " recurring_processing_model: #{@recurring_processing_model.inspect},"\
  " redirect_from_issuer_method: #{@redirect_from_issuer_method.inspect},"\
  " redirect_to_issuer_method: #{@redirect_to_issuer_method.inspect}, reference:"\
  " #{@reference.inspect}, return_url: #{@return_url.inspect}, risk_data:"\
  " #{@risk_data.inspect}, shopper_email: #{@shopper_email.inspect}, shopper_ip:"\
  " #{@shopper_ip.inspect}, shopper_interaction: #{@shopper_interaction.inspect},"\
  " shopper_locale: #{@shopper_locale.inspect}, shopper_name: #{@shopper_name.inspect},"\
  " shopper_reference: #{@shopper_reference.inspect}, shopper_statement:"\
  " #{@shopper_statement.inspect}, show_installment_amount:"\
  " #{@show_installment_amount.inspect}, show_remove_payment_method_button:"\
  " #{@show_remove_payment_method_button.inspect}, social_security_number:"\
  " #{@social_security_number.inspect}, split_card_funding_sources:"\
  " #{@split_card_funding_sources.inspect}, splits: #{@splits.inspect}, store:"\
  " #{@store.inspect}, store_filtration_mode: #{@store_filtration_mode.inspect},"\
  " store_payment_method: #{@store_payment_method.inspect}, store_payment_method_mode:"\
  " #{@store_payment_method_mode.inspect}, telephone_number: #{@telephone_number.inspect},"\
  " theme_id: #{@theme_id.inspect}, three_ds2_request_data:"\
  " #{@three_ds2_request_data.inspect}, three_ds_authentication_only:"\
  " #{@three_ds_authentication_only.inspect}, trusted_shopper: #{@trusted_shopper.inspect}>"
end

#to_custom_deliver_atObject



888
889
890
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 888

def to_custom_deliver_at
  DateTimeHelper.to_rfc3339(deliver_at)
end

#to_custom_expires_atObject



892
893
894
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 892

def to_custom_expires_at
  DateTimeHelper.to_rfc3339(expires_at)
end

#to_sObject

Provides a human-readable string representation of the object.



897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
# File 'lib/adyen_ap_is/models/create_checkout_session_request.rb', line 897

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_info: #{@account_info}, additional_amount: #{@additional_amount},"\
  " additional_data: #{@additional_data}, allowed_payment_methods:"\
  " #{@allowed_payment_methods}, amount: #{@amount}, application_info: #{@application_info},"\
  " authentication_data: #{@authentication_data}, billing_address: #{@billing_address},"\
  " blocked_payment_methods: #{@blocked_payment_methods}, capture_delay_hours:"\
  " #{@capture_delay_hours}, channel: #{@channel}, company: #{@company}, country_code:"\
  " #{@country_code}, date_of_birth: #{@date_of_birth}, deliver_at: #{@deliver_at},"\
  " delivery_address: #{@delivery_address}, enable_one_click: #{@enable_one_click},"\
  " enable_pay_out: #{@enable_pay_out}, enable_recurring: #{@enable_recurring}, expires_at:"\
  " #{@expires_at}, fund_origin: #{@fund_origin}, fund_recipient: #{@fund_recipient},"\
  " installment_options: #{@installment_options}, line_items: #{@line_items}, mandate:"\
  " #{@mandate}, mcc: #{@mcc}, merchant_account: #{@merchant_account},"\
  " merchant_order_reference: #{@merchant_order_reference}, metadata: #{@metadata}, mode:"\
  " #{@mode}, mpi_data: #{@mpi_data}, platform_chargeback_logic:"\
  " #{@platform_chargeback_logic}, recurring_expiry: #{@recurring_expiry},"\
  " recurring_frequency: #{@recurring_frequency}, recurring_processing_model:"\
  " #{@recurring_processing_model}, redirect_from_issuer_method:"\
  " #{@redirect_from_issuer_method}, redirect_to_issuer_method: #{@redirect_to_issuer_method},"\
  " reference: #{@reference}, return_url: #{@return_url}, risk_data: #{@risk_data},"\
  " shopper_email: #{@shopper_email}, shopper_ip: #{@shopper_ip}, shopper_interaction:"\
  " #{@shopper_interaction}, shopper_locale: #{@shopper_locale}, shopper_name:"\
  " #{@shopper_name}, shopper_reference: #{@shopper_reference}, shopper_statement:"\
  " #{@shopper_statement}, show_installment_amount: #{@show_installment_amount},"\
  " show_remove_payment_method_button: #{@show_remove_payment_method_button},"\
  " social_security_number: #{@social_security_number}, split_card_funding_sources:"\
  " #{@split_card_funding_sources}, splits: #{@splits}, store: #{@store},"\
  " store_filtration_mode: #{@store_filtration_mode}, store_payment_method:"\
  " #{@store_payment_method}, store_payment_method_mode: #{@store_payment_method_mode},"\
  " telephone_number: #{@telephone_number}, theme_id: #{@theme_id}, three_ds2_request_data:"\
  " #{@three_ds2_request_data}, three_ds_authentication_only:"\
  " #{@three_ds_authentication_only}, trusted_shopper: #{@trusted_shopper}>"
end